==> openstreetmap-client_12.07.4~ds0.orig.tar.gz: openstreetmap-client-12.07.4~ds0.orig/maps/__init__.py <==
# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
### BEGIN LICENSE
# Copyright (C) 2012 Sigurd Gartmann sigurdga-ubuntu@sigurdga.no
# This program is free software: you can redistribute it and/or modify it 
# under the terms of the GNU General Public License version 3, as published 
# by the Free Software Foundation.
# 
# This program is distributed in the hope that it will be useful, but 
# WITHOUT ANY WARRANTY; without even the implied warranties of 
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR 
# PURPOSE.  See the GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License along 
# with this program.  If not, see <http://www.gnu.org/licenses/>.
### END LICENSE

import sys
import optparse

import gettext
from gettext import gettext as _
gettext.textdomain('maps')

from maps.map_application import MapApplication
from maps_lib import set_up_logging, get_version

def parse_options():
    """Support for command line options"""
    parser = optparse.OptionParser(version="%%prog %s" % get_version())
    parser.add_option(
        "-v", "--verbose", action="count", dest="verbose",
        help=_("Show debug messages (-vv debugs maps_lib also)"))
    (options, args) = parser.parse_args()

    set_up_logging(options)

def main():
    # FIXME: Needs sys.argv two places, as do_open is not able to get the file
    # list

    parse_options()

    application = MapApplication(sys.argv)
    exit_status = application.run(sys.argv)
    sys.exit(exit_status)

if __name__ == "__main__":
    main()

==> openstreetmap-client_14.03.1~ds0.orig.tar.gz: openstreetmap-client-14.03.1~ds0.orig/maps/__init__.py <==
# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
### BEGIN LICENSE
# Copyright (C) 2012 Sigurd Gartmann sigurdga-ubuntu@sigurdga.no
# This program is free software: you can redistribute it and/or modify it 
# under the terms of the GNU General Public License version 3, as published 
# by the Free Software Foundation.
# 
# This program is distributed in the hope that it will be useful, but 
# WITHOUT ANY WARRANTY; without even the implied warranties of 
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR 
# PURPOSE.  See the GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License along 
# with this program.  If not, see <http://www.gnu.org/licenses/>.
### END LICENSE

import sys
import optparse

import locale
from locale import gettext as _
locale.textdomain('maps')

from maps.map_application import MapApplication
from maps_lib import set_up_logging, get_version

def parse_options():
    """Support for command line options"""
    parser = optparse.OptionParser(version="%%prog %s" % get_version())
    parser.add_option(
        "-v", "--verbose", action="count", dest="verbose",
        help=_("Show debug messages (-vv debugs maps_lib also)"))
    (options, args) = parser.parse_args()

    set_up_logging(options)

def main():
    # FIXME: Needs sys.argv two places, as do_open is not able to get the file
    # list

    parse_options()

    application = MapApplication(sys.argv)
    exit_status = application.run(sys.argv)
    sys.exit(exit_status)

if __name__ == "__main__":
    main()
